Fixing topology related interface/class tree

- (Mutable)Topology no longer implements ImmutableTopology

    --- BaseTopology (was ImmutableTopology)
     |
     +-- ImmutableTopology (new)
     |
     +-- MutableTopology (was Topology)
       |
       +-- RefreshableTopology
       |
       +-- TopologyInternal
            This interface is placed in wrong place. To be fixed later.

Change-Id: Ifa9defcc7c0fc22bba19977fe4ea57eaf792275e
diff --git a/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java b/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java
index b92518a..2a577f3 100644
--- a/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java
+++ b/src/main/java/net/onrc/onos/core/packetservice/PacketOutNotification.java
@@ -3,7 +3,7 @@
 import java.io.Serializable;
 import java.util.Arrays;
 
-import net.onrc.onos.core.topology.Topology;
+import net.onrc.onos.core.topology.MutableTopology;
 
 import com.google.common.collect.Multimap;
 
@@ -54,11 +54,11 @@
      * instance.
      *
      * @param localPorts the map of locally-controlled ports
      * @param topology an instance of the global topology
      * @return a multimap of ports that the packet should be sent out,
      * in the form
      * {@code {dpid1 => {portnum1, portnum2, ...}, dpid2 => {portnum1}, ...}}
      */
     public abstract Multimap<Long, Short> calculateOutPorts(
-            Multimap<Long, Short> localPorts, Topology topology);
+            Multimap<Long, Short> localPorts, MutableTopology mutableTopology);
 }
@@ -54,11 +54,11 @@
      *
      * @param localPorts the map of locally-controlled ports
-     * @param topology an instance of the global topology
+     * @param mutableTopology an instance of the global topology
      * @return a multimap of ports that the packet should be sent out,
      * in the form